#! /bin/sh
#
#   Module name 		: qinstall.sh 
#   Date of last delta		: 10/9/0
#   Release number		: 1.6


# Script name : qinstall.sh
# Purpose     : Quick install
# Author      : S. Roberts
# Revision    : 1.00

# Fix to make bash use /bin/echo for escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
    enable -n echo
fi


ensure_path()
{
	if [ -z "`echo $PATH|grep '\.'`" ]
	then
		# Path has not got . in it
		PATH=.:$PATH ; export PATH
		# It has now.
	fi
}


cls_sh()
{
	tput clear 2> /dev/null
	if [ $? != 0 ]
	then
		echo "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"
	fi
}


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


su_check()
{
	# Test if SuperUser
	# If $proc = 0 then SuperUser.
	proc=`id|sed s/uid=//|sed s/\(.*//`
}


check_4_quit()
{
	# If exit status is 1 then quit has been selected.
	if [ $? = "1" ]
	then
		exit
	fi
}


pause()
{
	echo
	echo "$spc Press [RETURN] to \c"
	if [ "$1" = "retry" ]
	then
		echo "retry: \c"
	else
		echo "continue: \c"
	fi
	read nothing
}


start_runtime_or_not()
{
	#echo
	#echo "$spc Do you want to start $PROD runtime? [Y]:$st_bl \c"
	#read answer
	#echo "$norm\c"
	#if [ "$answer" != "n" -a "$answer" != "N" ]
	#then
		startrun.sh -q
		check_4_quit
		if [ $? != 2 ]
		then
			call_UBL_or_not
		fi
	#else
	#	echo "$spc OK."
	#fi
}


call_UBL_or_not()
{
	echo
	echo "$spc Do you want to run $PROD now? [Y]: $st_bl \c"
	read answer
	echo "$norm\c"
	if [ "$answer" != "n" -a "$answer" != "N" ]
	then
		runubl.sh -q
		check_4_quit
	fi
}


menu1()
{
	cls_sh
	echo
	echo "$spc$st_us CREATE $PROD SYSTEM SOFTWARE DIRECTORY $norm  Rev $rev"
	echo
	echo "$spc DEFAULT $PROD System Software Directory [$st_bl$ubb_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or New Directory"
	echo
}


create_dir()
{
	# Check if directory already exists
	echo
	if [ -d $ubb_path ]
	then
		echo "\n$spc Directory $ubb_path already exists"
		ubb_path=$old_ubb
		pause retry
	else
		mkdir $ubb_path 2>/dev/null
		if [ $? -ne 0 ]
		then
			echo "\n$spc Error creating directory $ubb_path"
			ubb_path=$old_ubb
			pause retry
		else
			chmod a+rwx $ubb_path 2>/dev/null
			echo "$spc Directory $ubb_path created"
			ex_flag1=true
		fi
	fi
}


default_mkdir()
{
	mask="\/usr\/$prod"
	ubb_path=/usr/$prod

	while [ -d $ubb_path ]
	do
		ver=`echo $ubb_path|sed "s/$mask//"`
		ver=${ver:-"0"}
		ver1=`echo "$ver+1"|bc`
		ubb_path="/usr/$prod$ver1"
	done
}


createdir_sh()
{
	# This routine is the same as the installation
	# script 'createdir.sh', well almost.
	rev="1.00"
	ensure_path
	spc=""
	ex_flag1=false
	default_mkdir
	while [ $ex_flag1 = false ]
	do
		menu1
		echo "$spc Select option: $st_bl\c"
		read opt
		echo "$norm\c"
		case $opt in
			q | Q )		exit 1;;
			"^" )		ex_flag1=true;
					ubb_path=`pwd`;;
			d | D )		create_dir;;
			"" )		;;
			* )		old_ubb=$ubb_path
					ubb_path=$opt;
					create_dir;;
		esac
	done
}


menu2()
{
	cls_sh
	echo
	echo "$spc$st_us LOAD $PROD SYSTEM SOFTWARE FROM MEDIA $norm  Rev $rev"
	echo
	echo "$spc DEFAULT Current directory is [$st_bl$ubb_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or \c"
	echo "enter DIRECTORY PATH"
	echo
}


list_devices()
{
	echo "$st_bl\c" > delme.lis
	echo "Floppies:$norm" >> delme.lis
	ls -C /dev/fd* 2>/dev/null >> delme.lis
	echo >> delme.lis
	echo "$st_bl\c" >> delme.lis
	echo "Tapes:$norm" >> delme.lis
	ls -C /dev/rct* 2>/dev/null >> delme.lis
	ls -C /dev/rmt* 2>/dev/null >> delme.lis
	ls -C /dev/rmt/* 2>/dev/null >> delme.lis
	more delme.lis
	rm delme.lis
}


tar_files()
{
	device=$1
	tar_exit=false
	rm -f zzzzzzzzzz ubl/zzzzzzzzzz 2>/dev/null
	while [ $tar_exit = false ]
	do
		if [ $device = "def" ]
		then
			tar -xv
		else
			tar -xvf $device
		fi
		tar_stat=$?
		if [ ! -f zzzzzzzzzz -a ! -f ubl/zzzzzzzzzz -a $tar_stat = 0 ]
		then
			carry_on
		else
			tar_exit=true
		fi
	done
	rm -f zzzzzzzzzz ubl/zzzzzzzzzz 2>/dev/null
}


def_no_tar()
{
	device=$1
	tar_exit=false
	tar_stat=0
	rm -f zzzzzzzzzz 2>/dev/null
	while [ $tar_exit = false ]
	do
		tar -xv$device
		tar_stat=$?
		if [ ! -f zzzzzzzzzz -a $tar_stat = 0 ]
		then
			carry_on
		else
			tar_exit=true
		fi
	done
	rm -f zzzzzzzzzz 2>/dev/null
}


carry_on()
{
	echo
	echo "$spc Please insert next tape/diskette and \c"
	echo "press [RETURN] to extract: $st_bl\c"
	read ans
	echo "$norm"
}


abortion()
{
	echo
	echo "$spc An error has occured reading media."
	echo
	echo "$spc Please ensure that the correct device is being used and"
	echo "$spc you have inserted the media in the correct drive with"
	echo "$spc the door closed."
	echo
}


load_ubb()
{
	if [ -r $ubb_path -a -w $ubb_path -a -x $ubb_path ]
	then
		load="Y"
		if [ -s $ubb_path/$f_name ]
		then
			echo
			echo "$spc $PROD already exists in directory $ubb_path"
			echo "$spc Enter 'q' to QUIT, '^' to GO BACK , 'y' or OVERWRITE"
			ex_flag2=false
			while [ $ex_flag2 = false ]
			do
				echo "$spc Select option: $st_bl\c"
				read load
				echo "$norm\c"
				case $load in
					q | Q )		exit 1;;
					"^" )		load="N";
							ex_flag2=true;;
					y | Y )		ex_flag2=true;;
					l | L )		ex_flag2=true;;
					* )		;;
				esac
			done
		fi
		if [ $load = "y" -o $load = "Y" ]
		then
			err_flag=true
			while [ $err_flag = true ]
			do
				cls_sh
				list_devices
				echo
				echo "$spc Please ensure that the first tape\c"
				echo "/diskette is in the drive."
				echo "$spc Enter 'q' to QUIT, name of Device \c"
				echo "or [RETURN] to use default: $st_bl\c"
				read device
				echo "$norm\c"
				if [ ${device:-" "} = " " ]
				then
					echo
					echo "$spc Using default device.       \c"
					echo "Please wait ..."
					cd $ubb_path
					tar_files def
					if [ $tar_stat != 0 ]
					then
						abortion
						pause retry
					else
						echo
						echo "$spc Loading software completed."
						echo
						err_flag=false
						ex_flag1=true
					fi
				else
					if [ $device = q -o $device = Q ]
					then
						exit 1
					fi

					if [ -r $device ]
					then
						echo
						echo "$spc Using device $device        \c"
						echo "Please wait ..."
						cd $ubb_path
						tar_files $device
						if [ $tar_stat != 0 ]
						then
							abortion
							pause retry
						else
							echo
							echo "$spc Loading software completed."
							echo
							err_flag=false
							ex_flag1=true
						fi
					else
						echo "$spc Can not open device $device"
						pause
					fi
				fi
				if [ `echo $device|grep "^[0-9]*$" >/dev/null; echo $?` = 0 ]
				then
					echo
					echo "$spc Using device number $device.          \c"
					echo "Please wait ..."
					cd $ubb_path
					def_no_tar $device
					if [ $tar_stat != 0 ]
					then
						abortion
						pause retry
					else
						echo
						echo "$spc Loading software completed."
						echo
						err_flag=false
						ex_flag1=true
					fi
				fi
			done
		fi
	else
		echo
		if [ -d $ubb_path ]
		then
			echo
			echo "$spc Permissions for $ubb_path needs setting to +rwx"
		else
			echo
			echo "$spc Directory $ubb_path not found"
			ubb_path=$old_ubb
		fi
		pause
	fi

	if [ -f ubl.Z ]
	then
		echo "Uncompressing ubl executable..."
		rm ubl
		uncompress ubl
	fi
}


loadsoft_sh()
{
	rev="1.00"
	spc=""
	ex_flag1=false
	ensure_path
	while [ $ex_flag1 = false ]
	do
		menu2
		echo "$spc Select option: $st_bl\c"
		read opt
		echo "$norm\c"
		case $opt in
			q | Q )		exit 1;;
			"^" )		exit 2;;
			d | D )		load_ubb;;
			"" )		;;
			* )		old_ubb=$ubb_path
					ubb_path=$opt;
					load_ubb;;
		esac
	done
}


default_mkdir_ubb()
{
	mask="\/usr\/$prod"
	ubb_path=/usr/$prod

	while [ -d $ubb_path ]
	do
		ver=`echo $ubb_path|sed "s/$mask//"`
		ver=${ver:-"0"}
		ver1=`echo "$ver+1"|bc`
		ubb_path="/usr/ubl$ver1"
	done
}


danger()
{
	echo
	echo "$spc WARNING, some $PROD files already exist in this directory."
	echo "$spc Installing this new release of $PROD will overwrite these files."
	echo
	echo "$spc Do you want to create a new directory for $PROD? [Y]: \c"
	read ans
	if [ "$ans" = "Y" -o "$ans" = "y" -o "$ans" = "" ]
	then
		default_mkdir_ubb
		createdir_sh
	fi
}


print_update_note()
{
	cls_sh
	echo
	echo "$spc Do you want to print out the current update notice? [Y]: $st_bl\c"
	read ans
	echo "$norm\c"
	if [ "$ans" = "Y" -o "$ans" = "y" -o "$ans" = "" ]
	then
		if [ $PROD = U/SQL ]
		then
			usqllp.sh usrdata/usqlrel.*
		else
			ubllp.sh `ls UPDNOTE.[0-9][0-9][0-9]  2>/dev/null| sort | tail -1`
		fi
	else
		echo
		echo "$spc To print at a later date, type the following at the"
		echo "$spc shell prompt while in the $PROD system software directory:"
		echo
		if [ $PROD = U/SQL ]
		then
			echo $spc$st_bl   usqllp.sh `pwd`/usrdata/usqlrel.* $norm
		else
			echo "$spc$st_bl   ubllp.sh `ls UPDNOTE.[0-9][0-9][0-9] 2>/dev/null | sort | tail -1`$norm"
			
		fi
		echo
	fi
}


change_mode()
{
	# Argument list too long to do just a chmod.
	echo
	echo "$spc Checking permissions, please wait ... \c"
	find $ubb_path -exec chmod +rwx {} \;
	echo
	echo
}


update_file()
{
	head -`expr $line_no - 1` $infile > $tmp_file
	echo $their_new_path >> $tmp_file
	tail +`expr $line_no + 1` $infile >> $tmp_file

	# Use `cp` instead of `mv` to keep permissions:
	cp $tmp_file $infile
	rm $tmp_file
}


append_new_path()
{
	if [ $PROD = U/SQL ]
	then
		echo "PATH=\$PATH:$ubb_path/progs; export PATH" >> $infile
	else
		echo "PATH=\$PATH:$ubb_path; export PATH" >> $infile
	fi
}


add_to_path()
{
	# This routine adds the UBL system software directory on to the
	# search list in /etc/profile.

	infile=/etc/profile
	tmp_file=/tmp/updprofile.$$

	their_path=`grep "^PATH=" $infile | sed "s/PATH\=//"`
	line_no=`grep -n "^PATH=" $infile | sed "s/\:.*//"`
	# check to see if directory all ready in path
	if [ -n "$their_path" ]
	then
		if [ -z "`echo $their_path | grep $ubb_path$sub_dir`" ]
		then
			their_new_path="PATH=$ubb_path$sub_dir:$their_path"
			update_file
		fi
	else
		append_new_path
	fi

	PATH=$PATH:$ubb_path$sub_dir; export PATH
}


menu3()
{
	cls_sh
	echo
	echo "$spc$st_us SELECT AViiON RELEASE OR 88OPEN $norm  Rev $rev"
	echo
	echo "$spc Select 1 for AViiON"
	echo "$spc         or"
	echo "$spc        2 for 88open"
	echo
	echo
}


AViiONrelease()
{
	# The AViiON release structure has now been changed to inlude
	# the 88open release in case customer has an out of date version
	# of DG/UX insatlled.  DG/UX binaries are not backwards compatable.

	if [ -d 88open -a -d aviion ]
	then
		# This is an AViiON release.

		rev="1.00"
		spc=""
		ex_flag1=false
		ensure_path
		while [ $ex_flag1 = false ]
		do
			menu3
			echo "$spc Select option: $st_bl\c"
			read opt
			echo "$norm\c"
			case $opt in
				1 )	cd aviion;
					ex_flag1=true;;
				2 )	cd 88open;
					ex_flag1=true;;
			esac
		done
		ubb_path=`pwd`
	fi
}

# Main
umask 000
set_attrs
if [ -n "`pwd | grep [Uu][Ss][Qq][Ll]`" ]
then
	PROD="U/SQL"
	prod=usql
	f_name=runusql
	f_type=f
	sub_dir=/progs
else
	PROD="UBL"
	prod=ubl
	f_name=ubl
	f_type=f
	sub_dir=
fi
spc=""
ubb_path=""
old_ubb=""
ensure_path
proc=""

su_check
if [ $proc = "0" ]
then
	# check for Aviion structure - shiped with usqlcs
	if [ -d ubl ]
	then
		cd ubl
	fi
	ubb_path=`pwd`
	if [ -f ./ubl -o -f ./ublmon -o -f ./BBENV -o -f ./runusql -o -d ./88open -o -d aviion ]
	then
		danger
		pause
	fi
	loadsoft_sh
	# check for Aviion structure - shiped with usqlcs
	if [ -d ubl ]
	then
		cd ubl
		ubb_path=`pwd`
	fi
	AViiONrelease
	export ubb_path
	if [ $PROD = UBL ]
	then
		add_to_path
	fi
	change_mode
	pause
	if [ $PROD = UBL ]
	then
		createnv.sh -q
		check_4_quit
		pause
	fi
	print_update_note
	pause
	if [ $PROD = UBL ]
	then
		start_runtime_or_not
	else
		usqladm.sh
	fi
	echo
	echo "$spc $PROD installation complete."
else
	echo
	echo
	echo "$spc        You are not superuser.  Can not continue."
	echo
	echo "$spc        Please logon as 'root' or use the Unix command"
	echo "$spc        'su' to become superuser."
	echo
	echo "$spc        Type './QINSTALL.SH' to run this script again."
	echo	
	echo
fi
