#! /bin/sh
#
#   Module name 		: createdir.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : createdir.sh
# Purpose     : Creates the UBL System software directory.
# Author      : S. Roberts
# Revision    : 1.00


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc$st_us CREATE $PROD SYSTEM SOFTWARE DIRECTORY $norm  Rev $rev"
	echo
	echo "$spc DEFAULT $PROD System Software Directory [$st_bl$ubb_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or New Directory"
	echo
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


create_dir()
{
	# Check if directory already exists
	echo
	if [ -d $ubb_path ]
	then
		echo "\n$spc Directory $ubb_path already exists"
		ubb_path=$old_ubb
		pause
	else
		mkdir $ubb_path 2>/dev/null
		if [ $? -ne 0 ]
		then
			echo "\n$spc Error creating directory $ubb_path"
			ubb_path=$old_ubb
			pause
		else
			chmod a+rwx $ubb_path 2>/dev/null
			echo "$spc Directory $ubb_path created"
			ex_flag1=true
		fi
	fi
}


default_mkdir()
{
	case $PROD in
		UBL )		dirnam=ubl;;
		U/SQL )		dirnam=usql;;
		* )		echo "Dont be silly!";
				exit 1;;
	esac
	mask="\/usr\/$dirnam"
	ubb_path=/usr/$dirnam

	while [ -d $ubb_path ]
	do
		ver=`echo $ubb_path|sed "s/$mask//"`
		ver=${ver:-"0"}
		ver1=`echo "$ver+1"|bc`
		ubb_path="/usr/$dirnam$ver1"
	done
}


# main
rev="1.00"
if [ -n "`pwd | grep usql`" ] ; then PROD="U/SQL" ; else PROD="UBL" ; fi
set_attrs
spc=""
old_ubb=
ex_flag1=false
default_mkdir
while [ $ex_flag1 = false ]
do
	menu
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	case $opt in
		q | Q )		exit 1;;
		"^" )		exit 2;;
		d | D )		old_ubb=$ubb_path;
				create_dir;;
		"" )		;;
		* )		old_ubb=$ubb_path;
				ubb_path=$opt;
				create_dir;;
	esac
done
