#! /bin/sh
#
#   Module name 		: relist.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.4


# LOAD and LIST UBL programs to BBSOURCE
#
# UBL save files must be in the current directory,
# UBL must be accessible via search list.


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


where_is_it()
{
	finished=false
	where=

	while [ $finished = false ]
	do
		if [ -d $1 ]
		then
			# expand path
			a=`cd $1;pwd`
			if [ -f $a/BBENV ]
			then
				# YeEpEe! Found it.
				where=$a/BBENV
				finished=true
			else
				shift
				if [ -z "$1" ]
				then
					finished=true
				fi
			fi
		fi
	done
}


is_ubb ()
{
	# Is $1 a UBL save file?
	ubb_ver=`od -c $1 | sed "1q" | grep "^0000000* *036 *[a-ino]"`
	if [ -n "$ubb_ver" ]
	then
		save_file=true
	else
		save_file=false
	fi
}


find_bbsource ()
{
	if [ -z "$BBSOURCE" ]
	then
		if [ -z "$BBENV" ]
		then
			where_is_it `echo $PATH | sed "s/\:/ /g"`
			if [ -z "$where" ]
			then
				echo "BBENV not found"
				exit 1
			else
				get_bbsource $where
			fi
		else
			get_bbsource $BBENV
		fi
	else
		source=`echo $BBSOURCE|sed "s/\:.*//"`
	fi
	source=`echo "echo $source"|sh`
}


get_bbsource ()
{
	source=`grep "^BBSOURCE.*=" < $1|sed "s/BBSOURCE.*=//;s/\:.*//"`
	if [ -z "$source" ]
	then
		source=$BBROOT
		if [ -z "$source" ]
		then
			source=`grep "^BBROOT.*=" < $1|sed "s/BBROOT.*=//"`
		fi
	fi
}


# main

if [ -z "$1" ]
then
	echo "relist: No arguments"
	echo
	echo "Usage: relist filename [ ... ]"
	echo
	echo "Relist does the opposite to 'import', i.e. it LOADs and LISTs"
	echo "UBL 101 programs to BBSOURCE."
	echo
	echo "All UBL savefiles must be in the current directory and UBL"
	echo "accessible via search list."
	exit 1
fi
temp=`pwd`/fish
save_file=false
f_name=
source=
BBPROGS=`pwd`
export BBPROGS

find_bbsource
if [ -n "$source" ]
then
	source="$source/"
fi
echo "BBSOURCE is $source"
echo "Please wait..."
echo "\c" > $temp
while [ -n "$1" ]
do
	f_name=$1
	is_ubb $f_name
	if [ ! -f $source$f_name.bb ]
	then
		if [ -s $f_name -a $save_file = true ]
		then
			echo "new" >> $temp
			echo "load \"$f_name\"" >> $temp
			echo "list \"$f_name.bb\"" >> $temp
		else
			echo "$f_name is empty or not a UBL save file"
		fi
	else
		echo "WARNING: $source$f_name.bb all ready exists."
	fi
	shift
done

if [ -s $temp ]
then
	echo "bye" >> $temp
	ubl @$temp
	echo "Thats all folks"
fi

rm -f $temp 2>/dev/null
