#! /bin/sh
#
#   Module name 		: ubladm.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : ubladm.sh
# Purpose     : UBL system setup.
# Author      : S. Roberts
# Revision    : 1.00


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc        $st_us $PROD SYSTEM ADMINISTRATION $norm  Rev $rev"
	echo
	echo "$spc 1)$st_bl syssoft.sh $norm          $PROD System Software"
	#echo "$spc 2)$st_bl seckey.sh $norm           $PROD Security Key"
	echo "$spc 2)$st_bl perms.sh $norm            \c"
	echo "File and Directory Permissions"
	echo "$spc 3)$st_bl tdfutils.sh $norm         TDF Utilities"
	if [ "$PROD" = UBL ]
	then
		echo "$spc 4)$st_bl env.sh $norm              \c"
		echo "$PROD Environment"
		echo "$spc 5)$st_bl usrsoft.sh $norm          \c"
		echo "User Directory Structure"
		echo "$spc 6)$st_bl runtime.sh $norm          \c"
		echo "$PROD Runtime"
		echo "$spc 7)$st_bl ubllp.sh $norm            \c"
		echo "Print a file"
	else
		echo "$spc 4)$st_bl runtime.sh $norm          $PROD Runtime"
		echo "$spc 5)$st_bl ubllp.sh $norm            Print a file"
	fi
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT\n"
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
}


help_0()
{
	echo
	echo "$spc The $PROD System Administration utility provides the user"
	echo "$spc with an easy way to set up a tailored $PROD system."
	echo
	echo "$spc From installing the $PROD release software, through system"
	echo "$spc security, terminal definition, environment, directory"
	echo "$spc structure and $PROD's runtime, the $PROD System Administration"
	echo "$spc utility is a user-friendly, step-by-step approach to the"
	echo "$spc initial installation or subsequent modification of a $PROD"
	echo "$spc system."
	echo
}


help_1()
{
	echo
	echo "$spc The $PROD System Software option invokes another menu, which"
	echo "$spc gives the user access to the first steps involved in setting"
	echo "$spc up a new $PROD system."
	echo
	echo "$spc After creating a new directory for the $PROD release software,"
	echo "$spc the user can go on to install the software from the release"
	echo "$spc media.  Other options can be used to establish the $PROD"
	echo "$spc revision number, to remove the $PROD release software directory"
	echo "$spc or to install the on-line help (UBL only)."
	echo
}


#help_2()
#{
#	echo
#	echo "$spc The $PROD Security Key option allows the user to install,"
#	echo "$spc remove or check on the $PROD security key device driver."
#	echo
#}


help_2()
{
	echo
	echo "$spc The File and Directory Permissions option allows the user"
	echo "$spc to check or modify permissions on files and directories."
	echo
}


help_3()
{
	echo
	echo "$spc The TDF Utilities option invokes a menu that gives access"
	echo "$spc to the Terminal Definition File utilities."
	echo
	echo "$spc These utilities allow the user to change terminal type,"
	echo "$spc generate a new Terminal Definition File or modify an"
	echo "$spc existing one."
	echo
}


help_4()
{
	echo
	echo "$spc The $PROD Environment option invokes another menu, which"
	echo "$spc allows the user to create, view or edit a $PROD environment"
	echo "$spc variable file.  The menu includes another option which"
	echo "$spc can be used to find and display all of the $PROD environment"
	echo "$spc variable files on the system."
	echo
}


help_5()
{
	echo
	echo "$spc The User Directory Structure option invokes another menu,"
	echo "$spc which can be used to create those directories specified "
	echo "$spc in the UBL environment variable file."
	echo
}


help_6()
{
	echo
	echo "$spc The $PROD Runtime option invokes another menu, which allow"
	echo "$spc the user to start or stop the $PROD runtime, run ublmon or"
	echo "$spc $PROD itself."
	echo
}


help_7()
{
	echo
	echo "$spc The Print a file option will prompt the user for the"
	echo "$spc destination printer and then for the name of the file"
	echo "$spc that is to be printed.  This option could be used to"
	echo "$spc print out the $PROD release notice(s) that is supplied"
	echo "$spc with the release software."
	echo
}


check_4_quit()
{
	# If exit status is 1 then quit has been selected.
	if [ $? = "1" ]
	then
		exit
	fi
}


# Main
rev="1.00"
if [ -n "`pwd | grep usql`" ]
then
	PROD="U/SQL"
	f_name=runusql
	f_type=f
else
	PROD="UBL"
	f_name=ubl
	f_type=x
fi
set_attrs
spc=""
ubb_path=`where.sh $f_name $f_type`
if [ -z "${ubb_path}" ]
then
    ubb_path='.'
else
    ubb_path=`dirname $ubb_path`
fi
export ubb_path
ex_flag=false
while [ $ex_flag = false ]
do
	menu
	echo "$spc Select option: $st_bl\c"
	read main_opt
	echo "$norm\c"
	if [ $PROD = UBL ]
	then
		case $main_opt in
			1 )		syssoft.sh;
					check_4_quit;;
#			2 )		seckey.sh;
#					check_4_quit;;
			2 )		perms.sh;
					check_4_quit;;
			3 )		tdfutils.sh;
					check_4_quit;;
			4 )		env.sh;
					check_4_quit;;
			5 )		usrsoft.sh;
					check_4_quit;;
			6 )		runtime.sh;
					check_4_quit;;
			7 )		ubllp.sh;
					pause;;
	
			\? )		help_0;
					endhelp;;
			1\? )		help_1;
					endhelp;;
			2\? )		help_2;
					endhelp;;
			3\? )		help_3;
					endhelp;;
			4\? )		help_4;
					endhelp;;
			5\? )		help_5;
					endhelp;;
			6\? )		help_6;
					endhelp;;
			7\? )		help_7;
					endhelp;;

			q | Q )		exit 1;;
			"^" )		exit 2;;
		esac
	else
		case $main_opt in
			1 )		syssoft.sh;
					check_4_quit;;
#			2 )		seckey.sh;
#					check_4_quit;;
			2 )		perms.sh;
					check_4_quit;;
			3 )		tdfutils.sh;
					check_4_quit;;
			4 )		runtime.sh;
					check_4_quit;;
			5 )		ubllp.sh;
					pause;;
	
			\? )		help_0;
					endhelp;;
			1\? )		help_1;
					endhelp;;
			2\? )		help_2;
					endhelp;;
			3\? )		help_3;
					endhelp;;
			5\? )		help_6;
					endhelp;;
			6\? )		help_7;
					endhelp;;

			q | Q )		exit 1;;
			"^" )		exit 2;;
		esac
	fi
done
